#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    if os_info['platform'] == 'windows':
        return {'return': 1, 'error': 'Windows is not supported in this script yet'}

    env = i['env']

    env['IPEX_DIR'] = env['CM_IPEX_SRC_REPO_PATH']

    if env.get('CM_USE_LLVM_FOR_IPEX', '') == 'yes':
        env['DNNL_GRAPH_BUILD_COMPILER_BACKEND'] = 1
        env['USE_LLVM'] = env['CM_LLVM_INSTALLED_PATH']
        env['LLVM_DIR'] = os.path.join(
            env['CM_LLVM_INSTALLED_PATH'], "lib", "cmake", "llvm")

    run_cmd = "python setup.py clean && python setup.py install"

    env['CM_RUN_CMD'] = run_cmd

    return {'return': 0}


def postprocess(i):

    env = i['env']
    env['CM_IPEX_BUILD_PATH'] = os.path.join(os.getcwd(), "ipex_src", "build")
    env['CM_IPEX_INSTALLED_PATH'] = os.path.join(
        env['CM_IPEX_BUILD_PATH'],
        "Release",
        "packages",
        "intel_extension_for_pytorch")
    env['CM_DEPENDENT_CACHED_PATH'] = env['CM_IPEX_INSTALLED_PATH']

    return {'return': 0}



#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    env = i['env']

    meta = i['meta']

    automation = i['automation']

    quiet = (env.get('CM_QUIET', False) == 'yes')

    if env.get("CM_CALIBRATE_FILTER", "") == "yes":
        i['run_script_input']['script_name'] = "run-filter"
        env['CM_MLPERF_OPENIMAGES_CALIBRATION_FILTERED_LIST'] = os.path.join(
            os.getcwd(), "filtered.txt")
        env['CM_MLPERF_OPENIMAGES_CALIBRATION_LIST_FILE_WITH_PATH'] = env['CM_MLPERF_OPENIMAGES_CALIBRATION_FILTERED_LIST']

    return {'return': 0}


def postprocess(i):

    env = i['env']

    return {'return': 0}



#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    if os_info['platform'] == 'windows':
        return {'return': 1, 'error': 'Windows is not supported in this script yet'}

    env = i['env']

    run_cmd = "./build.sh --config RelWithDebInfo --build_wheel --parallel --allow_running_as_root --skip_tests "

    if env.get('CM_ONNXRUNTIME_GPU', '') == "yes":
        cuda_home = env['CUDA_HOME']
        run_cmd += f"--use_cuda --cuda_home {cuda_home} --cudnn_home {cuda_home}"

    env['CM_RUN_DIR'] = env['CM_ONNXRUNTIME_SRC_REPO_PATH']
    env['CM_RUN_CMD'] = run_cmd

    return {'return': 0}



#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    env = i['env']

    meta = i['meta']

    automation = i['automation']

    quiet = (env.get('CM_QUIET', False) == 'yes')

    if not env.get('CM_TORRENT_DOWNLOADED_FILE_NAME'):
        return {'return': 1, 'error': 'CM_TORRENT_DOWNLOADED_FILE_NAME is not set'}

    return {'return': 0}


def postprocess(i):

    env = i['env']
    torrent_downloaded_path = os.path.join(
        env['CM_TORRENT_DOWNLOADED_DIR'],
        env['CM_TORRENT_DOWNLOADED_NAME'])
    env['CM_TORRENT_DOWNLOADED_PATH'] = torrent_downloaded_path

    if 'CM_TORRENT_DOWNLOADED_PATH_ENV_KEY' in env:
        key = env['CM_TORRENT_DOWNLOADED_PATH_ENV_KEY']
        env[key] = torrent_downloaded_path

    env['CM_GET_DEPENDENT_CACHED_PATH'] = torrent_downloaded_path

    return {'return': 0}



#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    env = i['env']

    meta = i['meta']

    automation = i['automation']

    quiet = (env.get('CM_QUIET', False) == 'yes')

    if env.get('CM_NVIDIA_MLPERF_SCRATCH_PATH', '') == '':
        if env.get('MLPERF_SCRATCH_PATH', '') != '':
            env['CM_NVIDIA_MLPERF_SCRATCH_PATH'] = env['MLPERF_SCRATCH_PATH']
        else:
            env['CM_NVIDIA_MLPERF_SCRATCH_PATH'] = os.getcwd()

    return {'return': 0}


def postprocess(i):

    env = i['env']

    env['MLPERF_SCRATCH_PATH'] = env['CM_NVIDIA_MLPERF_SCRATCH_PATH']
    env['CM_GET_DEPENDENT_CACHED_PATH'] = env['CM_NVIDIA_MLPERF_SCRATCH_PATH']

    return {'return': 0}



#
# Copyright: https://github.com/mlcommons/ck/blob/master/cm-mlops/COPYRIGHT.md
# License: https://github.com/mlcommons/ck/blob/master/cm-mlops/LICENSE.md
#
# White paper: https://arxiv.org/abs/2406.16791
# History: https://github.com/mlcommons/ck/blob/master/HISTORY.CM.md
# Original repository: https://github.com/mlcommons/ck/tree/master/cm-mlops
#
# CK and CM project contributors: https://github.com/mlcommons/ck/blob/master/CONTRIBUTING.md
#

from cmind import utils
import os


def preprocess(i):

    os_info = i['os_info']

    env = i['env']

    return {'return': 0}


def postprocess(i):
    env = i['env']
    folder_name = env['CM_DATASET_ARCHIVE'].split(".")[0]
    env['CM_DATASET_LIBRISPEECH_PATH'] = os.path.join(
        os.getcwd(), "LibriSpeech", folder_name)
    env['CM_DATASET_PATH'] = os.path.join(
        os.getcwd(), "LibriSpeech", folder_name)

    return {'return': 0}
